@@ -11,11 +11,11 @@ Flexnet::lmutil - Convenient OO-interface for Flexnet license server utility lmu
 
 =head1 VERSION
 
-Version 1.2
+Version 1.3
 
 =cut
 
-our $VERSION = '1.2';
+our $VERSION = '1.3';
 
 =head1 DESCRIPTION
 
@@ -119,7 +119,8 @@ B<vendor> points to a structure like
  'vendor' => {
      'cdslmd' => {
          'ok' => 1,
-         'status' => 'UP'
+         'status' => 'UP v11.11',
+         'version' => '11.11'
      }
  }
 
@@ -276,10 +277,11 @@ sub lmstat {
 			}
 			
 		# vendor daemon status
-		} elsif ( my ($vendor, $state) = /^\s*(\S+?): (\S+)/ ) {
+		} elsif ( my ($vendor, $state) = /^\s*(\S+?): (.*)/ ) {
 			$status->{vendor}->{$vendor}->{status} = $state;
-			if ( $state eq 'UP' ) {
+			if ( $state =~ /^UP v([\d.]+)/ ) {
 				$status->{vendor}->{$vendor}->{ok} = 1;
+				$status->{vendor}->{$vendor}->{version} = $1;
 			} else {
 				$status->{vendor}->{$vendor}->{ok} = 0;
 			}
